@@ -308,12 +308,15 @@ def udiff_list(left, right, stanzas, indent=0, use_ellipses=True):
 
     pos = 0
     while pos < len(left_a):
-        key = next(keys, len(left_a) - 1)
+        try:
+            key = next(keys)
+            sub_diff = in_one_level(
+                stanzas, predicate_count(left_a[:key],
+                                         lambda x: not isinstance(x, Gap)))
+        except StopIteration:
+            key = len(left_a) - 1
+            sub_diff = []
         assert key >= pos, (key, pos)
-        sub_diff = in_one_level(
-            stanzas, predicate_count(left_a[:key],
-                                     lambda x: not isinstance(x, Gap))
-        )
         pos_diff = key - pos
 
         if use_ellipses:
